agentle.mcp.servers
===================

.. automodule:: agentle.mcp.servers

   
   .. rubric:: Classes

   .. autosummary::
   
      MCPServerProtocol
      SSEMCPServer
      StreamableHTTPMCPServer
   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   mcp_server_protocol
   sse_mcp_server
   stdio_mcp_server
   streamable_http_mcp_server
